@@ -1,4 +1,4 @@
-from Slot import Slot, SlotType
+from Slot import Slot, SlotsType
 from Schedule import Schedule
 from Appointment import Appointment
 from MedeoxRestClient import MedeoxRestClient
